@@ -5,7 +5,7 @@ from ..models import *
 
 import string
 
-exocolumns = [
+basic_columns = [
 'name',
 'hostname',
 'ra', 'dec',
@@ -27,7 +27,36 @@ transit_columns = [
 'transit_ar',
 'transit_b']
 
-necessary_columns = exocolumns + transit_columns
+calculated_columns = [
+'a_over_rs',
+'b',
+'insolation',
+'relative_insolation',
+'log_relative_insolation',
+'teq',
+'planet_luminosity',
+'density',
+'surface_gravity',
+'distance_modulus',
+'escape_velocity',
+'escape_parameter',
+'angular_separation',
+'imaging_contrast',
+'stellar_luminosity',
+]
+
+
+table_columns = basic_columns + transit_columns
+attribute_columns = table_columns + calculated_columns
+
+
+method_columns = ['scale_height',
+                  'transmission_signal', 'transmission_snr',
+                  'emission_signal', 'emission_snr',
+                  'reflection_signal', 'reflection_snr',
+                  'stellar_brightness',
+                  'stellar_brightness_in_telescope_units',
+                  'depth_uncertainty']
 
 desired_columns = [
 'mass_uncertainty_upper',
@@ -43,7 +72,8 @@ default_plotkw = dict(color='black',
                       zorder=0,
                       marker='o',
                       linewidth=1,
-                      ink=True,
+                      respond_to_color=True,
+                      respond_to_size=True,
                       exact=False,
                       label_planets=False,
                       filled=True,
@@ -69,7 +99,7 @@ class Population(Talker):
 
     #kludge?
     _pithy = True
-    def __init__(self, standard, label='unknown', **plotkw):
+    def __init__(self, standard, label='unknown', verbose=False, **plotkw):
         '''
         Initialize a Population of exoplanets from a standardized table.
 
@@ -90,6 +120,7 @@ class Population(Talker):
         # keywords to use for plotting
         self.plotkw = plotkw
 
+        self._pithy = verbose == False
         # define some cleaned names and hostnames, for indexing
         try:
             self.standard['tidyname']
@@ -567,7 +598,7 @@ class Population(Talker):
         '''
 
         N = len(self.standard)
-        for k in necessary_columns:
+        for k in table_columns:
             try:
                 n = sum(self.standard[k].mask == False)
             except AttributeError:
@@ -586,7 +617,7 @@ class Population(Talker):
 
         return np.array([clean(name) in clean(x) for x in self.name]).nonzero()[0]
 
-    def correct(self, name, **kwargs):
+    def update_planet(self, name, **kwargs):
         '''
         Correct the properties of a particular planet,
         modifying its values in the standardized table.
@@ -820,6 +851,11 @@ class Population(Talker):
     def log_relative_insolation(self):
         return np.log10(self.relative_insolation)
 
+    @property
+    def relative_cumulative_xuv(self):
+        xuv_proxy = (self.stellar_luminosity/u.Lsun)**-0.6
+        return self.relative_insolation*xuv_proxy
+
     @property
     def teq(self):
         '''
@@ -830,6 +866,13 @@ class Population(Talker):
         A = 1
         return ((f*A/4/sigma)**(1/4)).to(u.K)
 
+    @property
+    def planet_luminosity(self):
+        '''
+        The bolometric luminosity of the planet (assuming zero albedo).
+        '''
+        return (self.teq**4*con.sigma_sb*4*np.pi*self.radius**2).to(u.W)
+
     @property
     def transit_depth(self):
         '''
@@ -1007,28 +1050,6 @@ class Population(Talker):
         volume = 4/3*np.pi*(self.radius)**3
         return (mass/volume).to('g/cm**3')
 
-    @property
-    def mu(self):
-        '''
-        The mean molecular weight of an atmosphere.
-        Here, assumed to be H/He-dominated at reasonable temperature.
-        '''
-
-        # for comparing planets of different compositions
-        return 2.32
-
-    @property
-    def scale_height(self):
-        '''
-        The scale height of the atmosphere, at equilibrium temperature.
-        '''
-        k = con.k_B
-        T = self.teq
-        mu = self.mu
-        m_p = con.m_p
-        g = self.surface_gravity
-        return (k*T/mu/m_p/g).to('km')
-
     @property
     def escape_velocity(self):
         '''
@@ -1056,7 +1077,7 @@ class Population(Talker):
 
         e_thermal = k*T
         e_grav = G*M*m_p/R
-        return e_grav/e_thermal
+        return (e_grav/e_thermal).decompose()
 
     @property
     def distance_modulus(self):
@@ -1066,22 +1087,33 @@ class Population(Talker):
         mu = 5*np.log10(self.distance/(10*u.pc))
         return mu
 
-    # FIXME -- how do we make it possible to change the threshold for inclusion?
-    @property
-    def transmission_signal(self, threshold=2):
+    def scale_height(self, mu=2.32):
         '''
-        What is the transit depth of 1 scale height of an H2-rich
+        The scale height of the atmosphere, at equilibrium temperature.
+        '''
+        k = con.k_B
+        T = self.teq
+        m_p = con.m_p
+        g = self.surface_gravity
+        return (k*T/mu/m_p/g).to('km')
+
+
+    def transmission_signal(self, mu=2.32, threshold=2):
+        '''
+        What is the transit depth of 1 scale height of an
         atmosphere transiting in front of the star.
 
         Parameters
         ----------
+        mu : float
+            Mean molecular weight (default 2.2 for H/He)
         threshold : float
             By how many sigma must the planet mass be detected?
 
         '''
         with np.errstate(invalid='ignore'):
 
-            H = self.scale_height
+            H = self.scale_height(mu)
             Rp = self.radius
             Rs = self.stellar_radius
             depth = (2*H*Rp/Rs**2).decompose()
@@ -1092,13 +1124,12 @@ class Population(Talker):
             return depth
 
 
-    @property
-    def reflection_signal(self):
+    def reflection_signal(self, albedo=1.0):
         '''
         What is the reflected light eclipse depth,
         for an albedo of 100%?
         '''
-        return 0.25*(self.radius/self.semimajor_axis).decompose()**2
+        return albedo*0.25*(self.radius/self.semimajor_axis).decompose()**2
 
 
     def emission_signal(self, wavelength=5*u.micron):
@@ -1160,118 +1191,156 @@ class Population(Talker):
         # return the
         return flux_in_photons.to('ph s^-1 m^-2 micron^-1')
 
-
-    def photons_in_one_HST_orbit(self, wavelength=1.4*u.micron,
-                                       R=20):
+    def stellar_brightness_in_telescope_units(self, telescope_name='JWST', **kw):
         '''
-        The number of photons that hit the Hubble Space
-        Telescope mirror, over the course of 1 HST orbit,
-        accounting for 50% loss due to Earth occultations.
+        The stellar brightness, converted to telescope units.
+
+        Parameters
+        ----------
+        telescope_name : str
+            The name of the telescope.
+
+        wavelength : astropy.unit.Quantity
+            The wavelength at which it should be calculated.
+
+        R : float
+            The spectral resolution at which the
+            telescope will bin wavelengths.
+
+        dt : astropy.units.quantity.Quantity
+            The time over which the telescope exposes.
         '''
 
+        # what counts as 1 "telescope unit" (e.g. JWST at R=20 at 5 microns for 1 hour)
+        telescope_unit = define_telescope_unit_by_name(telescope_name, **kw)
 
-        duty_cycle=0.5
-        dt = 1*u.def_unit('orbit',
-                          96*u.minute,
-                          doc=f'''
-                          This custom unit represents the
-                          the time of one HST orbit.
-                          ''')
+        # what's the photon flux (photons/m**2/s)
+        flux_in_photons = self.stellar_brightness(telescope_unit.wavelength)
 
-        telescope_unit = define_telescope_unit_by_name('HST',
-                                      wavelength=wavelength,
-                                      R=R,
-                                      dt=dt)
+        # quote the brightness as (for example) gigaphotons/JWST at R=20 at 5 microns in 1 hour
+        unit = lotsofphotons_unit/telescope_unit
+        return flux_in_photons.to(unit)
 
-        collecting_power = telescope_unit*duty_cycle
+    def depth_uncertainty(self, telescope_name='JWST',
+                                per_transit=False,
+                                dt=1*u.hour,
+                                **kw):
+        '''
+        What is the transit/eclipse depth uncertainty
+        with a particular telescope
+        at a particular wavelength
+        at a particular resolution?
 
-        b = self.stellar_brightness(wavelength=wavelength)
+        By default, this will be calculated for one transit.
+        Optionally, it can be calculated for a given amount of time instead.
 
-        return (b*collecting_power).decompose()
+        Parameters
+        ----------
+        telescope_name : str
+            The name of the telescope.
 
-    def photons_in_one_WFC3_orbit(self, **kw):
-        N = self.photons_in_one_HST_orbit(**kw)
-        throughput = 0.4
-        duty_cycle = 0.8
-        return N*throughput*duty_cycle
+        per_transit : bool
+            If True, calculate the depth uncertainty for one transit.
+            If False, calculate the depth uncertainty for a certain amount
+            of in-transit time. You likely want to specify `dt` as a
+            keyword argument to set that amount of in-transit time.
+            In either case, an out-of-transit baseline equal to the
+            total in-transit time will be assumed. This means the actual
+            time cost will be twice the transit duration or `dt` chosen,
+            and the depth uncertainty will be a factor sqrt(2) larger
+            than the pure photon noise binned to the relevant timescale.
 
-    def depth_uncertainty_in_one_WFC3_orbit(self, **kw):
-        N = self.photons_in_one_WFC3_orbit(**kw)/u.ph
-        sigma_D = 1/np.sqrt(N)
+        wavelength : astropy.unit.Quantity
+            The wavelength at which it should be calculated.
+
+        R : float
+            The spectral resolution at which the
+            telescope will bin wavelengths.
+
+        dt : astropy.units.quantity.Quantity
+            The time over which the telescope exposes. If `per_transit=True`,
+            this will be ignored. Otherwise, it will set the total amount
+            of in-transit time observed, assuming that an equal amount of
+            time will *also* be observed out of transit.
+        '''
+
+        # what counts as 1 "telescope unit" (e.g. JWST at R=20 at 5 microns for 1 hour)
+        telescope_unit = define_telescope_unit_by_name(telescope_name,
+                                                       dt=dt,
+                                                       **kw)
+
+        # what's the photon flux (photons/m**2/s)
+        flux_in_photons = self.stellar_brightness(telescope_unit.wavelength)
+
+        # what's the total collecting power?
+        if per_transit:
+            ratio_of_collecting_time = self.transit_duration/dt
+        else:
+            ratio_of_collecting_time = 1
+        collecting_power = 1*telescope_unit*ratio_of_collecting_time
+
+        # what's the total number of photons collected during transit
+        N = (flux_in_photons*collecting_power).to(u.ph).value
+
+        # what's the flux uncertainty on the time scale of one transit?
+        sigma = 1/np.sqrt(N)
+
+        # inflate by a factor of sqrt(2) for equal out-of-transit
         oot = np.sqrt(2)
-        return sigma_D*oot
+        sigma_depth = sigma*oot
 
-    def radius_uncertainty_in_one_WFC3_orbit(self, **kw):
-        Rs = self.stellar_radius
-        D = self.transit_depth
-        sigma_D = self.depth_uncertainty_in_one_WFC3_orbit(**kw)
-        sigma_Rp = (Rs*sigma_D/2/np.sqrt(D)).to(u.Rearth)
-        return sigma_Rp
+        return sigma_depth
 
-    def radius_uncertainty_in_one_WFC3_transit(self, **kw):
-        N_orbits = (self.transit_duration/(96*u.minute)).decompose()
-        per_orbit = self.radius_uncertainty_in_one_WFC3_orbit(**kw)
-        return per_orbit/np.sqrt(N_orbits)
-
-
-
-
-    def stellar_brightness_JWST(self, wavelength=5*u.micron):
+    def _get_noise_and_unit(self, telescope_name='JWST',
+                            per_transit=False,
+                            **kw):
         '''
-        The stellar brightness, converted to JWST units.
-
-        Parameters
-        ----------
-        wavelength : astropy.unit.Quantity
-            The wavelength at which it should be calculated.
+        Tiny helper to get the noise and the telescope_unit
+        for a telescope observation of a planet.
         '''
 
-        flux_in_photons = self.stellar_brightness(wavelength)
-        unit = photon_unit/JWST_transit_unit(wavelength)
-        return flux_in_photons.to(unit)
+        # figure out the noise
+        noise = self.depth_uncertainty(telescope_name=telescope_name, per_transit=per_transit, **kw)
 
-    def stellar_brightness_HST(self, wavelength=1.4*u.micron):
+        # create a telescope unit (mostly to get a default wavelength)
+        telescope_unit = define_telescope_unit_by_name(telescope_name, **kw)
+
+        return noise, telescope_unit
+
+    def emission_snr(self, telescope_name='JWST', **kw):
         '''
-        The stellar brightness, converted to HST units.
-
-        Parameters
-        ----------
-        wavelength : astropy.unit.Quantity
-            The wavelength at which it should be calculated.
+        What's the approximate S/N for the detection of the
+        thermal emission eclipse of a planet?
         '''
 
-        flux_in_photons = self.stellar_brightness(wavelength)
-        unit = photon_unit/HST_orbit_unit(wavelength)
-        return flux_in_photons.to(unit)
+        noise, telescope_unit = self._get_noise_and_unit(telescope_name=telescope_name, **kw)
+        signal = self.emission_signal(wavelength=telescope_unit.wavelength)
+        return signal/noise
 
-    # PICK UP FROM HERE! THESE ARE ALL RELATIVE, SHOULD WE MAKE THEM ABSOLUTE?
-    # (e.g. define a R=20-JWST-hour as m**2*s)
-    @property
-    def noisepertransit(self):
-        raise NotImplementedError('!')
-        return 1.0/np.sqrt(self.photons*self.transit_duration)
+    def reflection_snr(self, telescope_name='JWST', albedo=1, **kw):
+        '''
+        What's the approximate S/N for the detection of the
+        reflected light eclipse of a planet?
+        '''
 
-    @property
-    def noisepertime(self):
-        raise NotImplementedError('!')
-        return 1.0/np.sqrt(self.photons/self.transit_ar)
+        noise, telescope_unit = self._get_noise_and_unit(telescope_name=telescope_name, **kw)
+        signal = self.reflection_signal(albedo=albedo)
+        return signal/noise
 
-    @property
-    def noise(self):
-        return 1.0/np.sqrt(self.photons)
-
-
-    @property
-    def cheopsnoisepertransit(self):
-        raise NotImplementedError('!')
-        #150 ppm/min for a 9th magnitude star (in V)
-        cheopsnoiseperminute =  150.0/1e6/np.sqrt(10**(-0.4*(self.V - 9.0)))
-        durationinminutes = self.transit_duration*24.0*60.0
-        return cheopsnoiseperminute/np.sqrt(durationinminutes)
+    def transmission_snr(self, telescope_name='JWST', mu=2.32, threshold=2, **kw):
+        '''
+        What's the approximate S/N for the detection of the
+        reflected light eclipse of a planet?
+        '''
 
+        noise, telescope_unit = self._get_noise_and_unit(telescope_name=telescope_name, **kw)
+        signal = self.transmission_signal(mu=mu, threshold=threshold)
+        return signal/noise
 
     def scatter(self, xname, yname, c=None, s=None, names=True, xlog=True, ylog=True, **kw):
-        '''Plot one parameter against another.'''
+        '''
+        Quick tool to plot one parameter against another.
+        '''
         plt.ion()
         x, y = self.__getattr__(xname), self.__getattr__(yname)
         try:
