@@ -1,9 +1,10 @@
-from .Population import Population, PredefinedPopulation, necessary_columns
+from .Population import Population, PredefinedPopulation, attribute_columns, method_columns
 from .Exoplanets import *
+from .TransitingExoplanets import *
 from .TOI import *
 from .TOISubsets import *
 from .SolarSystem import *
-from .ExoplanetsSubset import *
+from .TransitingExoplanetsSubsets import *
 from .summary import *
 from .column_descriptions import *
 from .collections import *
